import kebabCase from 'lodash/fp/kebabCase';
import mapValues from 'lodash/fp/mapValues';
import curry from 'lodash/fp/curry';
import React from 'react';
var idCounter = {};
function uniqueId(prefix) {
  if (prefix === void 0) {
    prefix = '$highlightUi$';
  }
  if (!idCounter[prefix]) {
    idCounter[prefix] = 0;
  }
  idCounter[prefix] += 1;
  var id = idCounter[prefix];
  if (prefix === '$highlightUi$') {
    return "" + id;
  }
  return "" + prefix + id;
}
var noop = function () {};
function invariant(condition, message) {
  if (process.env.NODE_ENV !== 'development') {
    return;
  }
  if (!condition) {
    var error = new Error(message);
    error.name = 'Invariant Violation';
    throw error;
  }
}
var forkHandlers = function (handlers) {
  return function (e) {
    handlers.forEach(function (handler) {
      if (handler) handler(e);
    });
  };
};
function parseMetadata(metadata) {
  return metadata ? Object.keys(metadata).reduce(function (acc, key) {
    acc["data-" + kebabCase(key)] = metadata[key] || '';
    return acc;
  }, {}) : {};
}
/**
 * This function allows to generate a new object that
 * contains metadata with values suffixed with provided suffix
 *
 * @example
 *   ```ts
 *   suffixMetadata(metadata, 'inner')
 *   ```
 *
 * This function is curried:
 *
 * @example
 *   ```ts
 *   const { metadata } = props;
 *   const suffixedMeta = suffixMetadata(metadata);
 *   ...
 *   <div {...parseMetadata(suffixedMeta('innerPart1'))}>
 *     <div {...parseMetadata(suffixedMeta('innerPart2'))} />
 *   </div>
 *   ```
 *
 * @param {ComponentMetadata} metadata The original metadata object
 * @param {string} suffix A string to be added to the values of the original metadata object
 * @returns {ComponentMetadata} The metadata object with values containing suffixes
 */
var suffixMetadata = curry(function (metadata, suffix) {
  return mapValues(function (val) {
    return val + "-" + suffix;
  }, metadata);
});

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];
      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }
    return t;
  };
  return __assign.apply(this, arguments);
};
function getDisplayName(WrappedComponent) {
  return WrappedComponent.displayName || WrappedComponent.name || 'Component';
}
function withDeprecationWarning(WrappedComponent, migrationGuideLink) {
  var componentName = getDisplayName(WrappedComponent);
  var deprecationMessage = "\u26A0\uFE0F Deprecation Warning: " + componentName + " is now deprecated.";
  var migrationGuideMessage = migrationGuideLink ? " See " + migrationGuideLink + " for migration guidance." : '';
  var fullMessage = deprecationMessage + migrationGuideMessage;
  var DeprecatedComponent = function (props) {
    // Only show the deprecated warning in non-production environments
    if (process.env.NODE_ENV !== 'production') {
      console.warn(fullMessage);
    }
    return /*#__PURE__*/React.createElement(WrappedComponent, __assign({}, props));
  };
  DeprecatedComponent.displayName = "withDeprecationWarning(" + componentName + ")";
  return DeprecatedComponent;
}
export { forkHandlers, invariant, noop, parseMetadata, suffixMetadata, uniqueId, withDeprecationWarning };
//# sourceMappingURL=index.js.map
